from github import Github


def issue(token, title, body):
    g = Github(token)

    try:
        repo = g.get_repo("tman540/T.A.R.B.S.-Engine")
    except Exception as e:
        print("Unable to log in")
        print(f"Error: {e}")
        exit()

    try:
        repo.create_issue(title=title, body=body, labels=["bug"])
        print("Issue successfully submitted!")

    except Exception as e:
        print("Unable to submit issue")
        print(f"Error: {e}")
        exit()


def feature(token, title, body):
    g = Github(token)

    try:
        repo = g.get_repo("tman540/T.A.R.B.S.-Engine")
    except Exception as e:
        print("Unable to log in")
        print(f"Error: {e}")
        exit()

    title = "Feature Request: " + title
    try:
        repo.create_issue(title=title, body=body, labels=["feature"])
        print("Feature successfully submitted!")

    except Exception as e:
        print("Unable to submit feature")
        print(f"Error: {e}")
        exit()



from setuptools import setup
from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding="utf-8") as f:
    long_description = f.read()


setup(
    name='TARBSengine',
    version='1.0.0.2',
    packages=[''],
    url='https://github.com/tman540/T.A.R.B.S.-Engine',
    license='MIT',
    author='Steven Tautonico',
    author_email='stautonico@gmail.com',
    description='Totally Accurate RPG Battle Simulation Engine',
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3.6',
    ], install_requires=[]

)



import TARBSengine
import random

TARBSengine.debug = True
TARBSengine.enable_logging = True
TARBSengine.genlog()

player = TARBSengine.Player("Steve", 20, 20, 5, 10)
zombie = TARBSengine.Enemy("Dave", 20, 5, 9)

desert = TARBSengine.Battlefield("Desert", "A dry, hot, generic desert", player, zombie)
